From 7adfcbdd990b4e9fdc76229c314c89c730ae6373 Mon Sep 17 00:00:00 2001
From: Chris Lamb <lamby@debian.org>
Date: Fri, 24 Jul 2009 19:45:20 +0200
Subject: [PATCH 3/7] Try mounting USB block devices if cdrom-detect/try-usb is true. We reject the mountpoint if it does not have /.disk/info file. (Closes: #498143)

---
 packages/cdrom-detect/debian/cdrom-detect.postinst |   20 ++++++++++++++++++++
 .../cdrom-detect/debian/cdrom-detect.templates     |    5 +++++
 packages/cdrom-detect/debian/changelog             |    2 ++
 packages/cdrom-detect/debian/control               |    2 +-
 4 files changed, 28 insertions(+), 1 deletions(-)

diff --git a/packages/cdrom-detect/debian/cdrom-detect.postinst b/packages/cdrom-detect/debian/cdrom-detect.postinst
index 5ead814..ca38cb1 100755
--- a/packages/cdrom-detect/debian/cdrom-detect.postinst
+++ b/packages/cdrom-detect/debian/cdrom-detect.postinst
@@ -32,6 +32,26 @@ while true
 do
 	mounted=0
 
+	if db_get cdrom-detect/try-usb && [ "$RET" = "true" ]; then
+		devices="$(list-devices usb-partition)"
+		for device in $devices; do
+			if mount -t vfat -o ro,exec $device /cdrom &&
+			   [ -e /cdrom/.disk/info ]; then
+				log "CD-ROM mount succeeded: device=$device fstype=vfat"
+				mounted=1
+				db_set cdrom-detect/cdrom_device $device
+				break
+			else
+				log "CD-ROM mount failed: device=$device fstype=vfat"
+				umount /cdrom 2>/dev/null || true
+			fi
+		done
+	fi
+
+	if [ "$mounted" = "1" ]; then
+		break
+	fi
+
 	devices="$(list-devices cd; list-devices maybe-usb-floppy)"
 	for device in $devices; do
 		if mount -t iso9660 -o ro,exec $device /cdrom; then
diff --git a/packages/cdrom-detect/debian/cdrom-detect.templates b/packages/cdrom-detect/debian/cdrom-detect.templates
index 878f474..32e7615 100644
--- a/packages/cdrom-detect/debian/cdrom-detect.templates
+++ b/packages/cdrom-detect/debian/cdrom-detect.templates
@@ -123,3 +123,8 @@ Type: text
 #  Item in the main menu to select this package
 # :sl2:
 _Description: Detect and mount CD-ROM
+
+Template: cdrom-detect/try-usb
+Type: boolean
+Description: for internal use only
+ Preseed this to true to try to mount /cdrom from USB partitions.
diff --git a/packages/cdrom-detect/debian/changelog b/packages/cdrom-detect/debian/changelog
index 2fbf886..45855e9 100644
--- a/packages/cdrom-detect/debian/changelog
+++ b/packages/cdrom-detect/debian/changelog
@@ -5,6 +5,8 @@ cdrom-detect (1.32) UNRELEASED; urgency=low
 
   [ Chris Lamb ]
   * Append " fstype=iso9660" to mounting status messages.
+  * Try mounting USB block devices if cdrom-detect/try-usb is true. We reject
+    the mountpoint if it does not have /.disk/info file. (Closes: #498143)
 
  -- Colin Watson <cjwatson@debian.org>  Thu, 13 Aug 2009 14:29:04 +0100
 
diff --git a/packages/cdrom-detect/debian/control b/packages/cdrom-detect/debian/control
index bd2a567..b6a7aa9 100644
--- a/packages/cdrom-detect/debian/control
+++ b/packages/cdrom-detect/debian/control
@@ -10,6 +10,6 @@ Vcs-Svn: svn://svn.debian.org/d-i/trunk/packages/cdrom-detect
 Package: cdrom-detect
 XC-Package-Type: udeb
 Architecture: all
-Depends: ${misc:Depends}, hw-detect, di-utils (>= 1.48)
+Depends: ${misc:Depends}, hw-detect, di-utils (>= 1.72)
 XB-Installer-Menu-Item: 1300
 Description: Detect CDROM devices and mount the CD
-- 
1.6.3.3

